from ._yanchor import YanchorValidator
from ._y import YValidator
from ._xanchor import XanchorValidator
from ._x import XValidator
from ._visible import VisibleValidator
from ._transition import TransitionValidator
from ._tickwidth import TickwidthValidator
from ._ticklen import TicklenValidator
from ._tickcolor import TickcolorValidator
from ._templateitemname import TemplateitemnameValidator
from ._steps import StepsValidator
from ._pad import PadValidator
from ._name import NameValidator
from ._minorticklen import MinorticklenValidator
from ._lenmode import LenmodeValidator
from ._len import LenValidator
from ._font import FontValidator
from ._currentvalue import CurrentvalueValidator
from ._borderwidth import BorderwidthValidator
from ._bordercolor import BordercolorValidator
from ._bgcolor import BgcolorValidator
from ._activebgcolor import ActivebgcolorValidator
from ._active import ActiveValidator
